pub struct PaymentResponse {
pub request_id: String,
pub method_name: String,
pub details: Option<HashMap<String, Value>>,
pub shipping_address: Option<ContactAddress>,
pub shipping_option: Option<PaymentShippingOption>,
pub payer_name: Option<String>,
pub payer_email: Option<String>,
pub payer_phone: Option<String>,
}Expand description
Indicates the user has chosen a payment method and approved a payment request.
See: https://www.w3.org/TR/payment-request/#paymentresponse-interface
Fields
request_id: StringUnique ID from the original PaymentRequest.
method_name: StringPayment method chosen by the user.
details: Option<HashMap<String, Value>>Payment-method-specific transaction data.
shipping_address: Option<ContactAddress>shipping_option: Option<PaymentShippingOption>payer_name: Option<String>payer_email: Option<String>payer_phone: Option<String>Trait Implementations
Sourceimpl Clone for PaymentResponse
impl Clone for PaymentResponse
Sourcefn clone(&self) -> PaymentResponse
fn clone(&self) -> PaymentResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PaymentResponse
impl Debug for PaymentResponse
Sourceimpl<'de> Deserialize<'de> for PaymentResponse
impl<'de> Deserialize<'de> for PaymentResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PaymentResponse
impl PartialEq for PaymentResponse
Sourcefn eq(&self, other: &PaymentResponse) -> bool
fn eq(&self, other: &PaymentResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PaymentResponse
impl Serialize for PaymentResponse
impl StructuralPartialEq for PaymentResponse